@@ -15,12 +15,17 @@ def get_inchi(molecule):
     :class:`str`
         The InChI.
 
+    Raises
+    ------
+    :class:`ValueError`
+        If the InChI of `molecule` cannot be generated.
+
     """
 
-    return rdkit.MolToInchi(
-        mol=molecule.to_rdkit_mol(),
-        treatWarningAsError=True,
-    )
+    inchi = rdkit.MolToInchi(molecule.to_rdkit_mol())
+    if inchi:
+        return inchi
+    raise ValueError('The InChI of {molecule} was empty.')
 
 
 def get_inchi_key(molecule):
@@ -66,9 +71,9 @@ def get_smiles(molecule):
 
     """
 
-    rdkit_mol = molecule.to_rdkit_mol()
-    rdkit.AssignStereochemistryFrom3D(rdkit_mol)
+    rdkit_mol = molecule.with_canonical_atom_ordering().to_rdkit_mol()
     rdkit.SanitizeMol(rdkit_mol)
+    rdkit.AssignStereochemistryFrom3D(rdkit_mol)
     rdkit_mol = rdkit.RemoveHs(rdkit_mol)
 
     return rdkit.MolToSmiles(
